@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: wai-logger
-version: 2.2.4.1
-id: wai-logger-2.2.4.1-b4d6891e20083c91ee31e279044b2010
-key: wailo_5SmWuEinP5Z6qUjoTvkeI6
+version: 2.2.7
+id: wai-logger-2.2.7-be4dfe43e81d159502c14b31210da2fe
+key: wailo_5jc4us4fvd2FZ54RBiyOqy
 license: BSD3
 maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
 synopsis: A logging system for WAI
@@ -14,27 +14,25 @@ author: Kazu Yamamoto <kazu@iij.ad.jp>
 exposed: True
 exposed-modules:
     Network.Wai.Logger
-hidden-modules: Network.Wai.Logger.Apache Network.Wai.Logger.Date
-                Network.Wai.Logger.IP Network.Wai.Logger.IORef
+hidden-modules: Network.Wai.Logger.Apache Network.Wai.Logger.IP
+                Network.Wai.Logger.IORef
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/wai-logger-2.2.4.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/wai-logger-2.2.4.1
-data-dir: /usr/share/arm-linux-ghc-7.10.3/wai-logger-2.2.4.1
-hs-libraries: HSwai-logger-2.2.4.1-5SmWuEinP5Z6qUjoTvkeI6
+import-dirs: /usr/lib/ghc-7.10.3/site-local/wai-logger-2.2.7
+library-dirs: /usr/lib/ghc-7.10.3/site-local/wai-logger-2.2.7
+data-dir: /usr/share/arm-linux-ghc-7.10.3/wai-logger-2.2.7
+hs-libraries: HSwai-logger-2.2.7-5jc4us4fvd2FZ54RBiyOqy
 depends:
-    auto-update-0.1.3-4edf36ce78b71bfaad1ce3737442c65f
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
+    blaze-builder-0.4.0.2-290873936811c5be5456133d1e8642df
     byteorder-1.0.4-d0724ebba5f7969f1b97a3570748951d
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    case-insensitive-1.2.0.6-c6baeb35be7a5ef7e8151f5e00d87f59
-    easy-file-0.2.1-9b22ae8f4cbee2da82c99a0d82e5050c
-    fast-logger-2.4.3-07980efcfdf2821a6e4b588f1620bda1
-    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
+    case-insensitive-1.2.0.6-f940e4aded76d28f250fda2e1500b30b
+    fast-logger-2.4.6-432abdc0f5b043114ea69b7c4625cae5
+    http-types-0.9-abc209b9e91b870b477d7ec7669b4ae8
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
     unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
     unix-time-0.3.6-139be0d28d6f361941053e7ff9473819
-    wai-3.2.0.1-d9757c75f497737a542bd24e4c437c56
+    wai-3.2.1-82fcd8afd3d66bf63829f2c0f9ec2308
 haddock-interfaces: /usr/share/doc/haskell-wai-logger/html/wai-logger.haddock
 haddock-html: /usr/share/doc/haskell-wai-logger/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
